// Persistence of Vision Ray Tracer Scene Description File
// File: .pov
// Vers: 3.1
// Desc: Tutoriel sur l'Igloo-2 "Bonus": "Igloo by Night"
// Date: 20/04/00
// Auth: Alonso Eusebio Pablo pour Freelog #9 DPpresse

//-----------------------------------------DECLARATIONS--------------------------------------------

#version 3.1  // Permet d'utiliser les instructions propre  Pov v 3.1 

global_settings { assumed_gamma 1.0 }  // definition du Gamma

//-------------------------------Inclusions Standard de POV-Ray------------------------------------

#include "colors.inc"	// Declaration des couleurs standard
#include "textures.inc"	// Declaration des textures standard

//---------------------------------DEFINITION DE LA CAMERA-----------------------------------------

camera
{  // debut de la camera
  location  <2.5, 1.0, -2.0> // position de la camera <X Y Z>
  look_at   <0.0, 0.0,  0.0> // point de mire <X Y Z>
}  // fin de la camera

//----------------------------------FOND DE CIEL---------------------------------------------------

sky_sphere // sphere infinie
{  // debut du ciel
  pigment  // pigment de la sphere
  {
    gradient y  // dgrad vertical
    color_map { [0.0 color rgb <0.,0.,1.0>] [.1 color blue 0.2] } // couleurs: deux couleurs
  }
}  // fin du ciel


//------------------------------LUMIERE INTERIEURE-------------------------------------------------
light_source
{
  0*x // position initiale de la lumire
  color red 1.0  green .0  blue .0  // lumire Rouge
  translate <0, .40, 0> // translation du point lumineux en hauteur dans l'intrieur de l'Igloo
}

//------------------------------ZONE LUMINEUSE STANDARD--------------------------------------------

light_source
{  // debut de la source lumineuse
  0*x // position initiale de la lumire
  color <.1, .1, .6> // couleur de la lumire
  area_light
  <8, 0, 0> <0, 0, 8> // zone couverte par la lumiere (x * z)
  4, 4                // nombre total de lumiers dans la zone (4x*4z = 16)
  adaptive 0          // 0,1,2,3... 
  jitter              // ajoute un effet tamise aleatoire
  translate <40, 50, 40>   // <x y z> translation de la zone de lumire depuis son point d'origine
}  // fin de la source lumineuse


//--------------------------------------BANQUISE---------------------------------------------------
#declare banquise = difference{  // operation plan NOT sphere = banquise

plane   // Definition d'un plan infini
{
  y, // <X Y Z> normale de la surface,ici le vecteur Y
  0.0 // distance entre l'origine et la surface normale
  hollow on // autorise un pigment
  pigment  // texture simulant la neige boueuse
  {
  agate // motif de type agate
  agate_turb 0.3 //  turbulence [1.0]  
  }
}

sphere // Definition de la sphere
{
  <0, 0, 0> // centre <X Y Z>
  .8    // rayon

        pigment {   
                color White  //couleur blanche
                }
        translate <2.2, .0, -1.0>  // translation de la sphere avant l'operation<dX dY dZ>

} 

}   // fin de la creation de la banquise

object { banquise}  // insertion de la banquise

//-------------------------SURFACE DE L'EAU--------------------------------------------------
plane   // Definition d'un plan infini
{
  y, // <X Y Z> normale de la surface,ici le vecteur Y
  -.05 // distance entre l'origine et la surface normale
  hollow on //
   texture {  // dclaration de texture
      pigment { color red 0.0 green 0.07 blue 0.0 }  // couleur vert sombre
      finish {   // finition de la texture
         reflection 0.45  // indice de rfraction
         ambient 0.15     // indice de refration pour les parties dans l'ombre
         diffuse 0.6 phong 1.0 phong_size 80  // indice de diffusion et de lissage Phong
      }
    
   }
}
//----------------------------L'OBJET "IGLOO"------------------------------------------------------     

//------- Objet Bolen "Brut" qui sera usin

#declare Brut = union {  // Opration AND
         
         sphere // insertion d'une sphere 
                {
                  <0, 0, 0> // centre <X Y Z>
                  1.1       // rayon
                }

        cylinder  // insertion d'un cylindre
                {
                  0*x,  1.0*x,  0.8 // depart, arrivee, rayon
                }

        cylinder // insertion d'un deuxieme cylindre
                {
                  1.0*x,  1.3*x,  0.9 // depart, arrivee, rayon
                }            
  
  } // fin de l'object Brut
  
//------- Objet Bolen "Outil" qui servira d'outil

#declare Outil = union { 
        
        box // Insertion d'un paralllpipde
        {
          <-1.4, -1.4, -1.4>  // premier sommet <X1 Y1 Z1>
          < 1.4,  0,  1.4>  // sommet oppos <X2 Y2 Z2>
        }
        
        sphere // insertion d'une sphre 
                {
                  <0, 0, 0> // centre <X Y Z>
                  1       // rayon
                }

        cylinder  // insertion d'un cylindre
                {
                  0*x,  1.4*x,  0.7 // dpart, arrive, rayon
                }
  
  } // Fin de l'objet "Outil"

//------- Opration "Brut" NOT "Outil" = "Igloo"
  
#declare Igloo = difference
{
        object { Brut}
        object { Outil}
}
         

//--------------------INSERTION DE L'OBJET "IGLOO" DANS LA SCENE---------------------------------

object { Igloo //insertion de l'objet portant le label:"Igloo"

 pigment   // texture de l'Igloo
  {
    brick      color Gray, color White  // briques blanches avec joints gris
    brick_size <0.3,0.3,0.3>   // taille des blocs
    mortar     0.03       // epaisseur des joints
  }
}  // fin de l'insertion de l'Igloo

//------------------CREATION DU SAPIN--------------------------------------------------------------

 
//
#declare sapin = union { //dclartion d'une opration "AND" dont le rsultat se nome "sapin"

cylinder  // tronc
        {
         0*y,  0.5*y,  .05
        pigment {
                color Maroon   //couleur marron
                }
        }

cone   // cne de base
        {
          0.7*y,  0.0,  // Disque au sommet et rayon
          0.5*y, .25    // Disque a la base et rayon
        pigment {
                color Green     // couleur verte
                }
        }

cone    // cne du milieu
        {
          .95*y,  0.0,
          0.65*y, .20
        pigment {
                color Green
                }
        }

cone  //  cne du sommet
        {
        1.1*y,  0.0,
        0.9*y, .08
  
        pigment {
                color Green
                }
        }

} // Fin de la definition du sapin

//--------------------------INSERTION DU SAPIN DANS LA SCENE---------------------------------------
object { sapin 

translate <1., .0, -1.6>  // <dX dY dZ>  translation du sapin

} // fin de l'insertion du sapin

//--------------------------- BRAVO, VOUS AVEZ TOUT LU! RDV le mois prochain-----------------------